@@ -15,7 +15,7 @@ with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
 # This call to setup() does all the work
 setup(
     name="testcsg",
-    version="0.1.3",
+    version="0.1.4",
     description="Test CSG library",
     long_description=long_description,
     long_description_content_type="text/markdown",
@@ -34,7 +34,7 @@ setup(
         "Programming Language :: Python :: 3.9",
         "Operating System :: OS Independent"
     ],
-    packages=["clientAPI"],
+    packages=["clientAPI", "clientAPI.objects"],
     py_modules=["clientAPI.base", "clientAPI.client", "clientAPI.mixin", "clientAPI.utils"],
     include_package_data=True,
     install_requires=["flask", "requests"]
